window._JUPYTERLAB=window._JUPYTERLAB||{},(()=>{"use strict";var r={607:()=>{}},t={};function e(o){var n=t[o];if(void 0!==n)return n.exports;var i=t[o]={exports:{}};return r[o](i,i.exports,e),i.exports}e.m=r,e.c=t,e.o=(r,t)=>Object.prototype.hasOwnProperty.call(r,t),(()=>{e.S={};var r={},t={};e.I=(o,n)=>{n||(n=[]);var i=t[o];if(i||(i=t[o]={}),!(n.indexOf(i)>=0)){if(n.push(i),r[o])return r[o];e.o(e.S,o)||(e.S[o]={}),e.S[o];var a=[];return r[o]=a.length?Promise.all(a).then(()=>r[o]=1):1}}})(),e(607)})();